tests Package
=============

:mod:`test_authentication` Module
---------------------------------

.. automodule:: CMFDefault.browser.membership.tests.test_authentication
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_join` Module
-----------------------

.. automodule:: CMFDefault.browser.membership.tests.test_join
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_members` Module
--------------------------

.. automodule:: CMFDefault.browser.membership.tests.test_members
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_password` Module
---------------------------

.. automodule:: CMFDefault.browser.membership.tests.test_password
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`test_preferences` Module
------------------------------

.. automodule:: CMFDefault.browser.membership.tests.test_preferences
    :members:
    :undoc-members:
    :show-inheritance:

